@@ -98,7 +98,7 @@ Everything else would be identical to the previous example.
 
 =cut
 
-our $VERSION = '2.1.1';
+our $VERSION = '2.1';
 
 our ($color_names, $color_ids) = _color_list();
 
@@ -892,7 +892,7 @@ sub end {
 }
 
 # write to a log file, for debugging
-sub _elog {
+sub elog {
 	my ($mesg) = @_;
 	open(F, ">>", "elog.log");
 	print F "$mesg\n";
@@ -901,8 +901,6 @@ sub _elog {
 
 1;
 
-=back
-
 =head1 CALLBACK ROUTINES
 
 Callback routines for all entities are called each time I<animate>
